tools/c2man.pl

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Hi,

The recent ordinal renaming in shlwapi brought this up.

Cheers,
Jon

Changelog:

  Jon Griffiths <jon_p_griffiths@yahoo.com>
  +tools/c2man.pl
    Ensure we generate for -noname ordinals documented as '@'.






__________________________________
Do you Yahoo!?
The New Yahoo! Shopping - with improved product search
http://shopping.yahoo.com
--- wine/tools/c2man.pl	2003-08-13 19:29:23.000000000 +0100
+++ wine-develop/tools/c2man.pl	2003-09-27 09:25:11.000000000 +0100
@@ -635,8 +635,23 @@
 
   if ($comment->{COMMENT_NAME} eq "@")
   {
-    # Create an implementation name
-    $comment->{COMMENT_NAME} = $comment->{DLL_NAME}."_".$comment->{ORDINAL};
+    my $found = 0;
+
+    # Find the name from the .spec file
+    for (@{$spec_details->{EXPORTS}})
+    {
+      if (@$_[0] eq $comment->{ORDINAL})
+      {
+        $comment->{COMMENT_NAME} = @$_[2];
+        $found = 1;
+      }
+    }
+
+    if ($found == 0)
+    {
+      # Create an implementation name
+      $comment->{COMMENT_NAME} = $comment->{DLL_NAME}."_".$comment->{ORDINAL};
+    }
   }
 
   my $exported_names = $spec_details->{EXPORTED_NAMES};

[Index of Archives]     [Gimp for Windows]     [Red Hat]     [Samba]     [Yosemite Camping]     [Graphics Cards]     [Wine Home]

  Powered by Linux